@@ -1,22 +1,24 @@
 import ast
 from abc import ABC, abstractmethod
-from typing import List, Protocol, Tuple
+from typing import List, Protocol, Type
 
+from tryceratops.processors import Processor
 from tryceratops.violations import Violation
 
 from .exceptions import AnalyzerVisitException
 
 
-class BaseAnalyzer(ABC, ast.NodeVisitor):
-    EXPERIMENTAL = False
-    violation_code: Tuple[str, str]
+class BaseAnalyzer(ABC, Processor, ast.NodeVisitor):
+    violation_type: Type[Violation] = Violation
 
     def __init__(self):
         self.violations: List[Violation] = []
 
-    def _mark_violation(self, *nodes):
+    def _mark_violation(self, *nodes, **kwargs):
+        klass = self.violation_type
         for node in nodes:
-            self.violations.append(Violation.build(self.filename, self.violation_code, node))
+            violation = klass.build(self.filename, self.violation_code, node, **kwargs)
+            self.violations.append(violation)
 
     def check(self, tree: ast.AST, filename: str) -> List[Violation]:
         self.filename = filename
